==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_download.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_download.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("DOWLAN_1", "Download added to database.");
define("DOWLAN_2", "Download updated in database.");
define("DOWLAN_3", "Download deleted.");
define("DOWLAN_4", "Please tick the confirm box to delete the download");
define("DOWLAN_5", "There are no download categories defined yet, until you define some you cannot enter any downloads.");
define("DOWLAN_6", "No existing downloads");
define("DOWLAN_7", "Existing Downloads");

define("DOWLAN_11", "Category");
define("DOWLAN_12", "Name");
define("DOWLAN_13", "File");
define("DOWLAN_14", "Enter address if download is an external file");
define("DOWLAN_15", "Author");
define("DOWLAN_16", "Author Email");
define("DOWLAN_17", "Author Website");
define("DOWLAN_18", "Description");
define("DOWLAN_19", "Main image");
define("DOWLAN_20", "Thumbnail image");
define("DOWLAN_21", "Status");

define("DOWLAN_24", "Update Download");
define("DOWLAN_25", "Submit Download");

define("DOWLAN_27", "Download");
define("DOWLAN_28", "None");
define("DOWLAN_29", "Downloads Front Page");
define("DOWLAN_30", "Create Download");
define("DOWLAN_31", "Categories");
define("DOWLAN_32", "Downloads Options");
define("DOWLAN_33", "Are you sure you want to delete this download?");
define("DOWLAN_34", "Are you sure you want to delete this download category?");

define("DOWLAN_36", "deleted");
define("DOWLAN_37", "Parent");
define("DOWLAN_38", "No existing categories");
define("DOWLAN_39", "Download categories");
define("DOWLAN_40", "None - main parent");
define("DOWLAN_41", "Icon");
define("DOWLAN_42", "View Images");
define("DOWLAN_43", "Visible to");
define("DOWLAN_44", "Ticking will make the category visible to only users in that class");
define("DOWLAN_45", "Create Category");
define("DOWLAN_46", "Update Category");
define("DOWLAN_47", "Category created");
define("DOWLAN_48", "Category Updated");
define("DOWLAN_49", "Download Category");

define("DOWLAN_51", "Search/Refresh downloads");
define("DOWLAN_52", "Files");
define("DOWLAN_53", "Subcategory");
define("DOWLAN_54", "Download Options");
define("DOWLAN_55", "Number of downloads to display per page");
define("DOWLAN_56", "Sort by ");


define("DOWLAN_59", "Filename");

define("DOWLAN_62", "Ascending");
define("DOWLAN_63", "Descending");
define("DOWLAN_64", "Update Options");
define("DOWLAN_65", "Options Updated");
define("DOWLAN_66", "Enter filesize");
define("DOWLAN_67", "ID");
define("DOWLAN_68", "File Missing!");
define("DOWLAN_69", "Downloads handled by PHP");
define("DOWLAN_70", "Checking this will send all download requests through PHP.");
define("DOWLAN_100", "Activate Download Agreement");
define("DOWLAN_101", "Agreement Text");
define("DOWLAN_102", "Allow Comments?");
define("DOWLAN_103", "Remove from Uploads");
define("DOWLAN_104", "was removed from public uploads");
define("DOWLAN_105", "Back to Public Uploads");
define("DOWLAN_106", "May be download by");
define("DOWLAN_107", "Limit download count");
define("DOWLAN_108", "Limit download bandwidth");
define("DOWLAN_109", "every");
define("DOWLAN_110", "days");
define("DOWLAN_111", "kb");
define("DOWLAN_112", "Limits");
define("DOWLAN_113", "Userclass");
define("DOWLAN_114", "Add New Limit");
define("DOWLAN_115", "Update limits");
define("DOWLAN_116", "Limit for that userclass already exists");
define("DOWLAN_117", "Limit successfully added");
define("DOWLAN_118", "Limit not added - unknown error");
define("DOWLAN_119", "Limit successfully removed");
define("DOWLAN_120", "Limit not removed - unknown error");
define("DOWLAN_121", "Limit successfully updated");
define("DOWLAN_122", "Inactive");
define("DOWLAN_123", "Active - File is subject to download limits");
define("DOWLAN_124", "Active - File is NOT subject to download limits");
define("DOWLAN_125", "Download limits active");
define("DOWLAN_126", "Activation status updated");
define("DOWLAN_127", "Only enter filesize if the download is an external file");
define("DOWLAN_128", "Mirrors");
define("DOWLAN_129", "leave blank if not using mirrors");
define("DOWLAN_130", "Add another mirror");
define("DOWLAN_131", "Select local file");
define("DOWLAN_132", "Please enter mirror to use, then address to download");

define("DOWLAN_133", "Mirror updated in database");
define("DOWLAN_134", "Mirror saved in database");
define("DOWLAN_135", "Mirror deleted");
define("DOWLAN_136", "image");
define("DOWLAN_137", "Are you sure you want to delete this mirror?");
define("DOWLAN_138", "Existing Mirrors");
define("DOWLAN_139", "Address");
define("DOWLAN_140", "Upload local images to e107_files/downloadimages to show them here, or enter full address if image is remote");
define("DOWLAN_141", "Location");
define("DOWLAN_142", "Update Mirror");
define("DOWLAN_143", "Create Mirror");
define("DOWLAN_144", "No mirrors defined in mirror section.");

define("DOWLAN_145", "Download visible to");
define("DOWLAN_146", "Custom Download-denial message or URL");


define("DOWLAN_147", "Icon for empty category");
define("DOWLAN_148", "Check to update date stamp to current time");
define("DOWLAN_149", "Or click here to use an external file");

define("DOWLAN_150", "Email admin when broken download reported");
define("DOWLAN_151", "Broken-download reporting available to");

define("DOWLAN_152", "Couldn't move file");
define("DOWLAN_153", "Move file into download folder");

define("DOWLAN_154", "if using mirrors, select how they will be displayed");
define("DOWLAN_155", "Mirror display type:");
define("DOWLAN_156", "show mirror list, allow user to choose mirror");
define("DOWLAN_157", "use random mirror - no user choice");

define("DOWLAN_158", "Show sub-sub-categories on main download page");
define("DOWLAN_159", "Include sub-sub-category counts in subcategory counts");

?>

==> e107-1.0.0.tbz: www/e107/e107_languages/English/admin/lan_download.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_download.php $
|     $Revision: 12132 $
|     $Id: lan_download.php 12132 2011-04-12 21:25:31Z e107steved $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/
define("DOWLAN_1", "Download added to database.");
define("DOWLAN_2", "Download updated in database.");
define("DOWLAN_3", "Download deleted.");
define("DOWLAN_4", "Please tick the confirm box to delete the download");
define("DOWLAN_5", "There are no download categories defined yet, until you define some you cannot enter any downloads.");
define("DOWLAN_6", "No existing downloads");
define("DOWLAN_7", "Existing Downloads");

define("DOWLAN_11", "Category");
define("DOWLAN_12", "Name");
define("DOWLAN_13", "File");
define("DOWLAN_14", "Enter address if download is an external file");
define("DOWLAN_15", "Author");
define("DOWLAN_16", "Author Email");
define("DOWLAN_17", "Author Website");
define("DOWLAN_18", "Description");
define("DOWLAN_19", "Main image");
define("DOWLAN_20", "Thumbnail image");
define("DOWLAN_21", "Status");

define("DOWLAN_24", "Update Download");
define("DOWLAN_25", "Submit Download");

define("DOWLAN_27", "Download");
define("DOWLAN_28", "None");
define("DOWLAN_29", "Downloads Front Page");
define("DOWLAN_30", "Create Download");
define("DOWLAN_31", "Categories");
define("DOWLAN_32", "Downloads Options");
define("DOWLAN_33", "Are you sure you want to delete this download?");
define("DOWLAN_34", "Are you sure you want to delete this download category?");

define("DOWLAN_36", "deleted");
define("DOWLAN_37", "Parent");
define("DOWLAN_38", "No existing categories");
define("DOWLAN_39", "Download categories");
define("DOWLAN_40", "None - main parent");
define("DOWLAN_41", "Icon");
define("DOWLAN_42", "View Images");
define("DOWLAN_43", "Visible to");
define("DOWLAN_44", "Ticking will make the category visible to only users in that class");
define("DOWLAN_45", "Create Category");
define("DOWLAN_46", "Update Category");
define("DOWLAN_47", "Category created");
define("DOWLAN_48", "Category Updated");
define("DOWLAN_49", "Download Category");

define("DOWLAN_51", "Search/Refresh downloads");
define("DOWLAN_52", "Files");
define("DOWLAN_53", "Subcategory");
define("DOWLAN_54", "Download Options");
define("DOWLAN_55", "Number of downloads to display per page");
define("DOWLAN_56", "Sort by ");


define("DOWLAN_59", "Filename");

define("DOWLAN_62", "Ascending");
define("DOWLAN_63", "Descending");
define("DOWLAN_64", "Update Options");
define("DOWLAN_65", "Options Updated");
define("DOWLAN_66", "Enter filesize");
define("DOWLAN_67", "ID");
define("DOWLAN_68", "File Missing!");
define("DOWLAN_69", "Downloads handled by PHP");
define("DOWLAN_70", "Checking this will send all download requests through PHP.");
define("DOWLAN_100", "Activate Download Agreement");
define("DOWLAN_101", "Agreement Text");
define("DOWLAN_102", "Allow Comments?");
define("DOWLAN_103", "Remove from Uploads");
define("DOWLAN_104", "was removed from public uploads");
define("DOWLAN_105", "Back to Public Uploads");
define("DOWLAN_106", "May be download by");
define("DOWLAN_107", "Limit download count");
define("DOWLAN_108", "Limit download bandwidth");
define("DOWLAN_109", "every");
define("DOWLAN_110", "days");
define("DOWLAN_111", "kb");
define("DOWLAN_112", "Limits");
define("DOWLAN_113", "Userclass");
define("DOWLAN_114", "Add New Limit");
define("DOWLAN_115", "Update limits");
define("DOWLAN_116", "Limit for that userclass already exists");
define("DOWLAN_117", "Limit successfully added");
define("DOWLAN_118", "Limit not added - unknown error");
define("DOWLAN_119", "Limit successfully removed");
define("DOWLAN_120", "Limit not removed - unknown error");
define("DOWLAN_121", "Limit successfully updated");
define("DOWLAN_122", "Inactive");
define("DOWLAN_123", "Active - File is subject to download limits");
define("DOWLAN_124", "Active - File is NOT subject to download limits");
define("DOWLAN_125", "Download limits active");
define("DOWLAN_126", "Activation status updated");
define("DOWLAN_127", "Only enter filesize if the download is an external file");
define("DOWLAN_128", "Mirrors");
define("DOWLAN_129", "leave blank if not using mirrors");
define("DOWLAN_130", "Add another mirror");
define("DOWLAN_131", "Select local file");
define("DOWLAN_132", "Please enter mirror to use, then address to download");

define("DOWLAN_133", "Mirror updated in database");
define("DOWLAN_134", "Mirror saved in database");
define("DOWLAN_135", "Mirror deleted");
define("DOWLAN_136", "image");
define("DOWLAN_137", "Are you sure you want to delete this mirror?");
define("DOWLAN_138", "Existing Mirrors");
define("DOWLAN_139", "Address");
define("DOWLAN_140", "Upload local images to ".e_FILE."downloadimages to show them here, or enter full address if image is remote");
define("DOWLAN_141", "Location");
define("DOWLAN_142", "Update Mirror");
define("DOWLAN_143", "Create Mirror");
define("DOWLAN_144", "No mirrors defined in mirror section.");

define("DOWLAN_145", "Download visible to");
define("DOWLAN_146", "Custom Download-denial message or URL");


define("DOWLAN_147", "Icon for empty category");
define("DOWLAN_148", "Check to update date stamp to current time");
define("DOWLAN_149", "Or click here to use an external file");

define("DOWLAN_150", "Email admin when broken download reported");
define("DOWLAN_151", "Broken-download reporting available to");

define("DOWLAN_152", "Couldn't move file");
define("DOWLAN_153", "Move file into download folder");

define("DOWLAN_154", "if using mirrors, select how they will be displayed");
define("DOWLAN_155", "Mirror display type:");
define("DOWLAN_156", "show mirror list, allow user to choose mirror");
define("DOWLAN_157", "use random mirror - no user choice");

define("DOWLAN_158", "Show sub-sub-categories on main download page");
define("DOWLAN_159", "Include sub-sub-category counts in subcategory counts");

define("DOWLAN_160", "Prevent simultaneous downloads by individual users");
define("DOWLAN_161", "Using a splash page to delay the downloading of files");
?>
